==> haskell-hedgehog-1.1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.1.1
visibility:           public
id:                   hedgehog-1.1.1-IGyguiWGV969RUxwFYMe89
key:                  hedgehog-1.1.1-IGyguiWGV969RUxwFYMe89
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  294511193fa8fb18be7959d7e17a1e4d
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hedgehog-1.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hedgehog-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.1.1-IGyguiWGV969RUxwFYMe89
depends:
    ansi-terminal-0.11.1-3bF8hvpb5rt8AmpxYz60ww
    async-2.2.4-DsK1F0iuVhj9HaenwCyvAG
    barbies-2.0.3.1-EIh27m8OySy1igtwRfrJnT base-4.15.1.0
    bytestring-0.10.12.1
    concurrent-output-1.10.15-1rYeQeOuBBn5gvylCS4WVa containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2
    erf-2.0.0.0-HR6qYigvkwv59tgVmdiMH1 exceptions-0.10.4
    lifted-async-0.10.2.2-Ehrvmm7AU2A9dR33V2K4zq
    mmorph-1.2.0-rUcqJ8kf022ZNG6tH16A7
    monad-control-1.0.3.1-A10z0BeOAGys9XF8o3vyn mtl-2.2.2
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    primitive-0.7.3.0-H7ArDzjx1emFJWugXBDX59
    random-1.2.1-E3c41PA01kCLyHrUUW2INz
    resourcet-1.2.4.3-G64JY14korRHLD6U5EyRCs stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-Iv23bfaB9S7861wmKQfWW8
    wl-pprint-annotated-0.1.0.1-Ji9x6qfo2Q3KNHqSMJ8zY9

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-1.1.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.1.1
visibility:           public
id:                   hedgehog-1.1.1-A6iMlTxIvIkES82GwS7p91
key:                  hedgehog-1.1.1-A6iMlTxIvIkES82GwS7p91
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  2a96ebd0e317e8a8dac19ccfe3a42348
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hedgehog-1.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hedgehog-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.1.1-A6iMlTxIvIkES82GwS7p91
depends:
    ansi-terminal-0.11.1-9xju66iiRICIYdPcTuYy1O
    async-2.2.4-6KBqZB2hivBDO34h1S6aOW
    barbies-2.0.3.1-ZTqOT6Lgm69sNc48R9wI2 base-4.15.1.0
    bytestring-0.10.12.1
    concurrent-output-1.10.15-8SmO4h8y92nE1p0cfjG7ta containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2
    erf-2.0.0.0-HR6qYigvkwv59tgVmdiMH1 exceptions-0.10.4
    lifted-async-0.10.2.2-HBnun5S64yG2HoqE8fK0t3
    mmorph-1.2.0-rUcqJ8kf022ZNG6tH16A7
    monad-control-1.0.3.1-1UdV54K1izzABtSLaOUgnj mtl-2.2.2
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    primitive-0.7.3.0-B6KvZtRR9ic1ON19TSUO1W
    random-1.2.1-A5Ulfz0z0RHF2G56IKAQiN
    resourcet-1.2.4.3-8QEUKrJZiOgDF8Ll7eoXIn stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-DnLUIX7W73LJlURzsbBten
    wl-pprint-annotated-0.1.0.1-3XoMWDN7iXzCPiWgY4ws6c

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
